NLSL: Data Fields

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Data Types List
- Data Types
- Data Fields

- All
- Variables

- b
- d
- e
- f
- g
- i
- l
- m
- n
- r
- s
- t
- w
- x
- y

Here is a list of all data types members with links to the data types they belong to:

### - b -

- bed : wstruct
- bgnd : wstruct
- byte : fpdatum

### - d -

- dspy : wstruct

### - e -

- eb : wstruct
- el : wstruct
- er : wstruct
- et : wstruct

### - f -

- fgnd : wstruct
- flag : wstruct
- flag2 : wstruct

### - g -

- gc : wstruct
- gc1 : wstruct
- gc2 : wstruct
- gc3 : wstruct

### - i -

- indx : wstruct

### - l -

- led : wstruct

### - m -

- map : wstruct
- mode : wstruct

### - n -

- next : xarry
- number : fpdatum , i4_datum
- nx : wstruct
- ny : wstruct

### - r -

- red : wstruct

### - s -

- scrn : wstruct

### - t -

- ted : wstruct

### - w -

- wndw : wstruct
- word : i4_datum

### - x -

- x : xarry
- xmax : wstruct
- xmin : wstruct
- xstep : wstruct
- xye : wstruct
- xys : wstruct

### - y -

- ydif : wstruct
- ye : wstruct
- ymax : wstruct
- ymin : wstruct
- ys : wstruct
- yzer : wstruct